@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /*
@@ -1461,7 +1460,9 @@ static AddressDataSource *addrindex_parse_ldap( XMLFile *file ) {
 		}
 		g_free( criteria );
 	}
-	/* ldapsvr_print_data( server, stdout ); */
+#ifdef DEBUG_LDAP
+	ldapsvr_print_data( server, stdout );
+#endif
 
 	return ds;
 }
@@ -2168,7 +2169,9 @@ static gboolean addrindex_process_book( AddressIndex *addrIndex, XMLFile *file,
 
 	addrindex_process_node( abf, rootNode, abf->addressCache->rootFolder, NULL, NULL );
 
-	/* addrbook_dump_book( abf, stdout ); */
+#ifdef DEBUG_ADDRBOOK
+	addrbook_dump_book( abf, stdout );
+#endif
 	addrbook_save_data( abf );
 	addrIndex->retVal = abf->retVal;
 	if( abf->retVal == MGU_SUCCESS ) retVal = TRUE;
