@@ -1,5 +1,5 @@
-/* Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2014 Charles Lehner and the Claws Mail team
+/* Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 2014-2023 the Claws Mail team and Charles Lehner
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -394,9 +394,7 @@ void addrmerge_merge(
 
 	/* Test for read only */
 	if( ds->interface->readOnly ) {
-		alertpanel( _("Merge addresses"),
-			_("This address data is read-only and cannot be deleted."),
-			GTK_STOCK_CLOSE, NULL, NULL, ALERTFOCUS_FIRST );
+		alertpanel_warning(_("This address data is read-only and cannot be deleted."));
 		return;
 	}
 
