@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,6 @@
 
 #include "defs.h"
 
-#ifdef G_OS_WIN32
-#  include <w32lib.h>
-#endif
-
 #include <glib.h>
 #include <glib/gi18n.h>
 
@@ -128,6 +124,12 @@ void set_log_file(LogInstance instance, const gchar *filename)
 		g_free(fullname);
 		return;
 	}
+
+	if (change_file_mode_rw(log_fp[instance], fullname) < 0) {
+		FILE_OP_ERROR(fullname, "chmod");
+		g_warning("can't change file mode: %s", fullname);
+	}
+
 	log_filename[instance] = g_strdup(fullname);
 	log_size[instance] = 0;
 	g_free(fullname);
@@ -199,7 +201,7 @@ void log_print(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -230,7 +232,7 @@ void log_message(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -264,7 +266,7 @@ void log_warning(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -298,7 +300,7 @@ void log_error(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -332,7 +334,7 @@ void log_status_ok(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -366,7 +368,7 @@ void log_status_nok(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
@@ -400,7 +402,7 @@ void log_status_skip(LogInstance instance, const gchar *format, ...)
 	struct tm buft;
 
 	time(&t);
-	strftime(buf, LOG_TIME_LEN + 1, "[%H:%M:%S] ", localtime_r(&t, &buft));
+	strftime(buf, LOG_TIME_LEN + 1, LOG_TIME_FORMAT, localtime_r(&t, &buft));
 
 	va_start(args, format);
 	g_vsnprintf(buf + LOG_TIME_LEN, BUFFSIZE, format, args);
