@@ -19,10 +19,6 @@
 #ifndef __PROXY_H__
 #define __PROXY_H__
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <glib.h>
 
 #include "socket.h"
