@@ -51,6 +51,7 @@ struct _FolderView
 {
 	GtkWidget *scrolledwin;
 	GtkWidget *ctree;
+	GtkWidget *headerpopupmenu;
 
 	GHashTable *popups;
 
@@ -104,7 +105,7 @@ struct _FolderViewPopup
 };
 
 void folderview_initialize		(void);
-FolderView *folderview_create		(void);
+FolderView *folderview_create		(MainWindow *mainwin);
 void folderview_init			(FolderView	*folderview);
 
 void folderview_set			(FolderView	*folderview);
@@ -114,8 +115,7 @@ void folderview_select			(FolderView	*folderview,
 					 FolderItem	*item);
 void folderview_unselect		(FolderView	*folderview);
 void folderview_select_next_with_flag	(FolderView	*folderview,
-					 MsgPermFlags    flag,
-					 gboolean 	 force_open);
+					 MsgPermFlags    flag);
 
 FolderItem *folderview_get_selected_item(FolderView	*folderview);
 FolderItem *folderview_get_opened_item(FolderView	*folderview);
@@ -127,6 +127,8 @@ void folderview_check_new_all		(void);
 
 void folderview_update_all_updated	(gboolean	 update_summary);
 
+void folderview_run_processing(FolderItem *item);
+
 void folderview_move_folder		(FolderView 	*folderview,
 					 FolderItem 	*from_folder,
 					 FolderItem 	*to_folder,
@@ -146,6 +148,13 @@ void folderview_finish_dnd		(const gchar 		*data,
 					 GdkDragContext 	*drag_context,
 			   		 guint 			 time, 
 					 FolderItem 		*item);
-void folderview_close_opened		(FolderView 		*folderview);
+void folderview_close_opened		(FolderView 		*folderview,
+					 gboolean		 dirty);
+void folderview_remove_item(FolderView *folderview,
+			    FolderItem *item);
+
+void folderview_freeze(FolderView *folderview);
+void folderview_thaw(FolderView *folderview);
+void folderview_grab_focus(FolderView *folderview);
 
 #endif /* __FOLDERVIEW_H__ */
