@@ -1,10 +1,8 @@
 static char *TEAM_LIST[] = {
-"Holger Berndt <berndth@users.sf.net>",
 "Jonathan Boeing <jonathan@claws-mail.org>",
 "Tristan Chabredier <wwp@claws-mail.org>",
-"Darko Koruga <darko@users.sf.net>",
-"Paul Mangan <paul@claws-mail.org>",
 "Thorsten Maerz <thorsten@claws-mail.org>",
+"Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
 "Michael Rasmussen <mir@datanom.net>",
@@ -12,6 +10,7 @@ NULL
 };
 
 static char *EX_TEAM_LIST[] = {
+"Holger Berndt",
 "Hoà Viêt Dinh",
 "Keith Edmunds",
 "Match Grun",
@@ -21,6 +20,7 @@ static char *EX_TEAM_LIST[] = {
 "Alfons Hoogervorst",
 "Andrej Kacian",
 "Werner Koch",
+"Darko Koruga",
 "Charles Lehner",
 "Colin Leroy-Mira",
 "Paweł Pękala",
@@ -38,7 +38,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[ca] David Medina <opensusecatala@gmail.com>",
 "[cs] David Vachulka <david@konstrukce-cad.com>",
 "[da] Erik P. Olsen <epodata@gmail.com>",
-"[de] Simon Legner <simon.legner@gmail.com>",
+"[de] Simon Legner",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
@@ -49,7 +49,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
 "[nb] Petter Adsen <petter@synth.no>",
 "[nl] Marcel Pol <mpol@gmx.net>",
-"[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
+"[pl] Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
 "[pt_PT] Pedro Albuquerque <palbuquerque73@gmail.com>",
 "[ro] Cristian Secară <liste@secarica.ro>",
@@ -65,6 +65,7 @@ static char *DOC_TEAM_LIST[] = {
 "[en] Tristan Chabredier <wwp@claws-mail.org>",
 "     Ricardo Mones Lastra <ricardo@mones.org>",
 "     Paul Mangan <paul@claws-mail.org>",
+"[de] Christoph Klassen <christoph.klassen@intevation.de>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
 NULL
@@ -108,6 +109,7 @@ static char *CONTRIBS_LIST[] = {
 "Anton Butanaev",
 "Henrik Carlqvist",
 "Luca Cavalli",
+"Gianni Ceccarelli",
 "David Chalmers",
 "Wei-Lun Chao",
 "Guillaume Chazarain",
@@ -125,6 +127,7 @@ static char *CONTRIBS_LIST[] = {
 "Ben Deering",
 "Jean Delvare",
 "Pierric Descamps",
+"Orivej Desh",
 "Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
 "Tim Dijkstra",
@@ -155,7 +158,7 @@ static char *CONTRIBS_LIST[] = {
 "Yang Guilong",
 "Ashish Gupta",
 "Daniel Gustafson",
-"HIROSHIMA",
+"Roland Haas",
 "Oliver Haertel",
 "Anders Hammar",
 "Mitko Haralanov",
@@ -169,9 +172,11 @@ static char *CONTRIBS_LIST[] = {
 "Christian Hesse",
 "Higuchi",
 "Hiramatu",
+"HIROSHIMA",
 "Marc Hoper",
 "Michihide Hotta",
 "Shawn Houston",
+"Charles Huber",
 "Michael Hughes",
 "Richard Hughes",
 "Arthur Huillet",
@@ -222,10 +227,12 @@ static char *CONTRIBS_LIST[] = {
 "Bram Metsch",
 "Hanno Meyer-Thurow",
 "George Michaelson",
+"Raphael Michel",
 "Florian Mickler",
 "Neill Miller",
 "Suzuki Mio",
 "Alex S Moore",
+"Frank Mueller",
 "NAKAGAWA",
 "Yuuki NINOMIYA",
 "Satoshi Nagayasu",
@@ -258,6 +265,7 @@ static char *CONTRIBS_LIST[] = {
 "Quar",
 "Don Quijote",
 "Steve Rader",
+"Steve Randall",
 "Jens Rantil",
 "Ravemax",
 "Eric S. Raymond",
@@ -290,11 +298,13 @@ static char *CONTRIBS_LIST[] = {
 "Dale P. Smith",
 "Avinash Sonawane",
 "Andrea Spadaccini",
+"Manuel Stoeckl",
 "Bogdan Sumanariu",
 "TAKANO",
 "TOGAWA",
 "Tajiri",
 "Takahashi",
+"Sakaguchi Takayuki",
 "Tanaka",
 "Shimamoto \"Neko\" Tatsuya",
 "Timo Teräs",
@@ -310,6 +320,7 @@ static char *CONTRIBS_LIST[] = {
 "Aleksandar Urošević",
 "Petr Vanek",
 "Jeroen Versteeg",
+"Viatrix",
 "Kevin Vigor",
 "Michael Vilain",
 "Johan Vromans",
