@@ -45,7 +45,6 @@
 #include <sys/time.h>
 #include <fcntl.h>
 #include <time.h>
-#include <dirent.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -648,7 +647,6 @@ static void button_press_intercept_cb(GtkTextView *gtktext,
 static GtkAspeller *gtkaspeller_new(Dictionary *dictionary)
 {
 	GtkAspeller	*gtkaspeller = NULL;
-	GtkAspeller	*tmp;
 	Dictionary	*dict;
 
 	cm_return_val_if_fail(gtkaspellcheckers, NULL);
@@ -663,11 +661,6 @@ static GtkAspeller *gtkaspeller_new(Dictionary *dictionary)
 
 	dict = dictionary_dup(dictionary);
 
-	tmp = g_new0(GtkAspeller, 1);
-	tmp->dictionary = dict;
-
-	g_free(tmp);
-
 	if ((gtkaspeller = gtkaspeller_real_new(dict)) != NULL) {
 		gtkaspellcheckers->checkers = g_slist_append(
 				gtkaspellcheckers->checkers,
