@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
+ * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -745,7 +745,7 @@ void gtkut_widget_set_composer_icon(GtkWidget *widget)
 }
 
 static gboolean move_bar = FALSE;
-static gint move_bar_id = -1;
+static guint move_bar_id;
 
 static gboolean move_bar_cb(gpointer data)
 {
@@ -794,7 +794,7 @@ GtkWidget *label_window_create(const gchar *str)
 
 	gtk_widget_show_now(window);
 	
-	if (move_bar_id == -1) {
+	if (move_bar_id == 0) {
 		move_bar_id = g_timeout_add(200, move_bar_cb, wait_progress);
 		move_bar = TRUE;
 	}
@@ -808,7 +808,7 @@ void label_window_destroy(GtkWidget *window)
 {
 	move_bar = FALSE;
 	g_source_remove(move_bar_id);
-	move_bar_id = -1;
+	move_bar_id = 0;
 	GTK_EVENTS_FLUSH();
 	gtk_widget_destroy(window);	
 }
