@@ -31,7 +31,12 @@ typedef enum
 	IMAP_AUTH_DIGEST_MD5	= 1 << 4,
 	IMAP_AUTH_SCRAM_SHA1	= 1 << 5,
 	IMAP_AUTH_PLAIN   = 1 << 6,
-	IMAP_AUTH_LOGIN   = 1 << 7
+	IMAP_AUTH_LOGIN   = 1 << 7,
+	IMAP_AUTH_OAUTH2   = 1 << 8,
+	IMAP_AUTH_SCRAM_SHA224	= 1 << 9,
+	IMAP_AUTH_SCRAM_SHA256	= 1 << 10,
+	IMAP_AUTH_SCRAM_SHA384	= 1 << 11,
+	IMAP_AUTH_SCRAM_SHA512	= 1 << 12,
 } IMAPAuthType;
 
 FolderClass *imap_get_class		(void);
