@@ -362,7 +362,7 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 	name = trim_string(item->name, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
 	message = g_markup_printf_escaped
-		(_("All folders and messages under '%s' will be permanently deleted. "
+		(_("All folders and messages under '%s' will be permanently deleted.\n"
 		   "Recovery will not be possible.\n\n"
 		   "Do you really want to delete?"), name);
 	avalue = alertpanel_full(_("Delete folder"), message,
