@@ -589,8 +589,8 @@ void mimeview_destroy(MimeView *mimeview)
 	mimeview_free_mimeinfo(mimeview);
 	gtk_tree_path_free(mimeview->opened);
 	g_free(mimeview->file);
-	g_free(mimeview);
 	mimeviews = g_slist_remove(mimeviews, mimeview);
+	g_free(mimeview);
 }
 
 MimeInfo *mimeview_get_selected_part(MimeView *mimeview)
@@ -2241,9 +2241,10 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 				g_chmod(filename, S_IRUSR|S_IWUSR);
  		} else {
 			g_warning("MIME viewer command-line is invalid: '%s'", cmd);
+			cmd = NULL;
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
  		}
-		if (execute_command_line(buf, TRUE, NULL) != 0) {
+		if (cmd != NULL && execute_command_line(buf, TRUE, NULL) != 0) {
 			if (!prefs_common.save_parts_readwrite)
 				g_chmod(filename, S_IRUSR|S_IWUSR);
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
