@@ -37,12 +37,16 @@
 #include "prefs_common.h"
 #include "prefs_gtk.h"
 #include "prefs_migration.h"
+#include "file-utils.h"
 
 static GSList *_password_store;
 
-/* Finds password block of given type and name in the pwdstore. */
+/* Finds password block of given type and name in the pwdstore
+ * and returns a pointer to it, if it exists.
+ * If link parameter is non-null, it is set to the linked list
+ * element containing this block. */
 static PasswordBlock *_get_block(PasswordBlockType block_type,
-		const gchar *block_name)
+		const gchar *block_name, GSList **link)
 {
 	GSList *item;
 	PasswordBlock *block;
@@ -53,8 +57,11 @@ static PasswordBlock *_get_block(PasswordBlockType block_type,
 	for (item = _password_store; item != NULL; item = item->next) {
 		block = (PasswordBlock *)item->data;
 		if (block->block_type == block_type &&
-				!strcmp(block->block_name, block_name))
+				!strcmp(block->block_name, block_name)) {
+			if (link != NULL)
+				*link = item;
 			return block;
+		}
 	}
 
 	return NULL;
@@ -77,7 +84,7 @@ static PasswordBlock *_new_block(PasswordBlockType block_type,
 	g_return_val_if_fail(block_name != NULL, NULL);
 
 	/* First check to see if the block doesn't already exist. */
-	if (_get_block(block_type, block_name)) {
+	if (_get_block(block_type, block_name, NULL)) {
 		debug_print("Block (%d/%s) already exists.\n",
 				block_type, block_name);
 		return NULL;
@@ -98,6 +105,19 @@ static PasswordBlock *_new_block(PasswordBlockType block_type,
 	return block;
 }
 
+static void _delete_block(PasswordBlock *block)
+{
+	g_return_if_fail(block != NULL);
+
+	if (block->block_name != NULL)
+		g_free(block->block_name);
+
+	if (block->entries != NULL)
+		g_hash_table_destroy(block->entries);
+
+	g_free(block);
+}
+
 /*************************************************************/
 
 /* Stores a password. */
@@ -121,13 +141,8 @@ gboolean passwd_store_set(PasswordBlockType block_type,
 	else
 		p = password;
 
-	debug_print("%s password '%s' in block (%d/%s)%s\n",
-			(p == NULL ? "Deleting" : "Storing"),
-			password_id, block_type, block_name,
-			(encrypted ? ", already encrypted" : "") );
-
 	/* find correct block (create if needed) */
-	if ((block = _get_block(block_type, block_name)) == NULL) {
+	if ((block = _get_block(block_type, block_name, NULL)) == NULL) {
 		/* If caller wants to delete a password, and even its block
 		 * doesn't exist, we're done. */
 		if (p == NULL)
@@ -142,9 +157,16 @@ gboolean passwd_store_set(PasswordBlockType block_type,
 
 	if (p == NULL) {
 		/* NULL password was passed to us, so delete the entry with
-		 * corresponding id */
-		g_hash_table_remove(block->entries, password_id);
+		 * corresponding id, if it exists */
+		if (g_hash_table_lookup(block->entries, password_id) != NULL) {
+			debug_print("Deleting password for '%s' in block (%d/%s)\n",
+					password_id, block_type, block_name);
+			g_hash_table_remove(block->entries, password_id);
+		}
 	} else {
+		debug_print("Setting password for '%s' in block (%d/%s)%s\n",
+				password_id, block_type, block_name,
+				(encrypted ? ", already encrypted" : ""));
 		if (!encrypted) {
 			/* encrypt password before saving it */
 			if ((encrypted_password =
@@ -183,7 +205,7 @@ gchar *passwd_store_get(PasswordBlockType block_type,
 			password_id, block_type, block_name);
 
 	/* find correct block */
-	if ((block = _get_block(block_type, block_name)) == NULL) {
+	if ((block = _get_block(block_type, block_name, NULL)) == NULL) {
 		debug_print("Block (%d/%s) not found.\n", block_type, block_name);
 		return NULL;
 	}
@@ -221,7 +243,7 @@ gboolean passwd_store_has_password(PasswordBlockType block_type,
 	g_return_val_if_fail(password_id != NULL, FALSE);
 
 	/* find correct block */
-	if ((block = _get_block(block_type, block_name)) == NULL) {
+	if ((block = _get_block(block_type, block_name, NULL)) == NULL) {
 		debug_print("Block (%d/%s) not found.\n", block_type, block_name);
 		return FALSE;
 	}
@@ -239,6 +261,7 @@ gboolean passwd_store_delete_block(PasswordBlockType block_type,
 		const gchar *block_name)
 {
 	PasswordBlock *block;
+	GSList *link = NULL;
 
 	g_return_val_if_fail(block_type < NUM_PWS_TYPES, FALSE);
 	g_return_val_if_fail(block_name != NULL, FALSE);
@@ -246,13 +269,14 @@ gboolean passwd_store_delete_block(PasswordBlockType block_type,
 	debug_print("Deleting block (%d/%s)\n", block_type, block_name);
 
 	/* find correct block */
-	if ((block = _get_block(block_type, block_name)) == NULL) {
+	if ((block = _get_block(block_type, block_name, &link)) == NULL) {
 		debug_print("Block (%d/%s) not found.\n", block_type, block_name);
 		return FALSE;
 	}
 
-	g_hash_table_destroy(block->entries);
-	block->entries = NULL;
+	/* free the block data and remove it from the list */
+	_delete_block(block);
+	_password_store = g_slist_delete_link(_password_store, link);
 	return TRUE;
 }
 
@@ -306,7 +330,7 @@ void passwd_store_reencrypt_all(const gchar *old_mpwd,
 		debug_print("Reencrypting passwords in block (%d/%s).\n",
 				block->block_type, block->block_name);
 
-		if (g_hash_table_size(block->entries) == 0)
+		if (block->entries == NULL || g_hash_table_size(block->entries) == 0)
 			continue;
 
 		keys = g_hash_table_get_keys(block->entries);
@@ -348,16 +372,16 @@ static gint _write_to_file(FILE *fp)
 
 	/* Write out the config_version */
 	line = g_strdup_printf("[config_version:%d]\n", CLAWS_CONFIG_VERSION);
-	if (fputs(line, fp) == EOF) {
-		FILE_OP_ERROR("password store, config_version", "fputs");
+	if (claws_fputs(line, fp) == EOF) {
+		FILE_OP_ERROR("password store, config_version", "claws_fputs");
 		g_free(line);
 		return -1;
 	}
 	g_free(line);
 
 	/* Add a newline if needed */
-	if (_password_store != NULL && fputs("\n", fp) == EOF) {
-		FILE_OP_ERROR("password store", "fputs");
+	if (_password_store != NULL && claws_fputs("\n", fp) == EOF) {
+		FILE_OP_ERROR("password store", "claws_fputs");
 		return -1;
 	}
 
@@ -368,7 +392,7 @@ static gint _write_to_file(FILE *fp)
 			continue; /* Just in case. */
 
 		/* Do not save empty blocks. */
-		if (g_hash_table_size(block->entries) == 0)
+		if (block->entries == NULL || g_hash_table_size(block->entries) == 0)
 			continue;
 
 		/* Prepare the section header string and write it out. */
@@ -382,8 +406,8 @@ static gint _write_to_file(FILE *fp)
 		}
 		line = g_strdup_printf("[%s:%s]\n", typestr, block->block_name);
 
-		if (fputs(line, fp) == EOF) {
-			FILE_OP_ERROR("password store", "fputs");
+		if (claws_fputs(line, fp) == EOF) {
+			FILE_OP_ERROR("password store", "claws_fputs");
 			g_free(line);
 			return -1;
 		}
@@ -397,8 +421,8 @@ static gint _write_to_file(FILE *fp)
 				continue;
 
 			line = g_strdup_printf("%s %s\n", key, pwd);
-			if (fputs(line, fp) == EOF) {
-				FILE_OP_ERROR("password store", "fputs");
+			if (claws_fputs(line, fp) == EOF) {
+				FILE_OP_ERROR("password store", "claws_fputs");
 				g_free(line);
 				return -1;
 			}
@@ -407,8 +431,8 @@ static gint _write_to_file(FILE *fp)
 		g_list_free(keys);
 
 		/* Add a separating new line if there is another block remaining */
-		if (item->next != NULL && fputs("\n", fp) == EOF) {
-			FILE_OP_ERROR("password store", "fputs");
+		if (item->next != NULL && claws_fputs("\n", fp) == EOF) {
+			FILE_OP_ERROR("password store", "claws_fputs");
 			return -1;
 		}
 
@@ -508,6 +532,7 @@ int passwd_store_read_config(void)
 						debug_print("config_version:%d looks invalid, ignoring it\n",
 								config_version);
 						config_version = -1; /* set to default value if missing */
+						g_strfreev(line);
 						i++; continue;
 					}
 					debug_print("config_version in file is %d\n", config_version);
