@@ -21,6 +21,8 @@
  * Functions necessary to access Pine address book file.
  */
 
+#include "config.h"
+
 #include <sys/stat.h>
 #include <glib.h>
 #include <string.h>
@@ -195,10 +197,8 @@ static void pine_free_rec( Pine_ParsedRec *rec ) {
 		g_free( rec->address );
 		g_free( rec->fcc );
 		g_free( rec->comments );
-		mgu_clear_slist( rec->listName );
-		mgu_clear_slist( rec->listAddr );
-		g_slist_free( rec->listName );
-		g_slist_free( rec->listAddr );
+		g_slist_free_full( rec->listName, g_free );
+		g_slist_free_full( rec->listAddr, g_free );
 		rec->nickName = NULL;
 		rec->name = NULL;
 		rec->address = NULL;
@@ -578,7 +578,7 @@ static void pine_read_file( PineFile *pineFile, AddressCache *cache ) {
 				}
 				g_free( lineValue );
 				lineValue = NULL;
-				mgu_free_list( listValue );
+				g_slist_free_full( listValue, g_free );
 				listValue = NULL;
 			}
 			if( line != NULL ) {
@@ -593,7 +593,7 @@ static void pine_read_file( PineFile *pineFile, AddressCache *cache ) {
 	}
 
 	/* Release data */
-	mgu_free_list( listValue );
+	g_slist_free_full( listValue, g_free );
 	listValue = NULL;
 }
 
