@@ -124,7 +124,7 @@ static void folder_permission_cb(GtkWidget *widget, gpointer data) {
 			".claws-mail/mimetmp",
 			".claws-mail/tmp",
 			NULL};
-	const gchar* home = g_get_home_dir();
+	const gchar* home = get_home_dir();
 	int i;
 
 	check_permission((gchar *) home);
@@ -509,7 +509,7 @@ static void clamav_save_func(PrefsPage *_page)
 		Clamd_Stat status = clamd_prepare();
 		switch (status) {
 			case NO_SOCKET: 
-				g_warning("[New config] No socket information");
+				g_warning("[New config] no socket information");
 				alertpanel_error(_("New config\nNo socket information.\nAntivirus disabled."));
 				break;
 			case NO_CONNECTION:
