@@ -16,9 +16,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <sys/stat.h>
 
 #include "libravatar_cache.h"
+#include "file-utils.h"
 #include "utils.h"
 
 gchar *libravatar_cache_init(const char *dirs[], gint start, gint end)
