@@ -16,6 +16,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <stdio.h>
 
 #include "libravatar_federation.h"
@@ -24,6 +26,7 @@
 
 #define MISSING "x"
 
+#if defined USE_GNUTLS
 static GHashTable *federated = NULL;
 
 /**
@@ -68,6 +71,7 @@ static void add_federated_url_for_domain(const gchar *url, const gchar *domain)
 	debug_print("new cached avatar url for domain %s: %s\n", domain, url);
 	g_hash_table_insert(federated, g_strdup(domain), g_strdup(url)); 
 }
+#endif
 
 /**
  * Retrieves the federated URL for a given email address.
@@ -78,6 +82,7 @@ static void add_federated_url_for_domain(const gchar *url, const gchar *domain)
  */
 gchar *federated_url_for_address(const gchar *address)
 {
+#if defined USE_GNUTLS
 	gchar *domain = NULL, *last = NULL, *addr = NULL, *url = NULL;
 	gchar *host = NULL;
 	guint16 port = 0;
@@ -142,5 +147,9 @@ invalid_addr:
 
 	debug_print("invalid address for libravatar federated domain\n");
 	return NULL;
+#else
+	debug_print("federated domains disabled (built without GnuTLS support)\n");
+	return NULL;
+#endif
 }
 
