@@ -18,6 +18,8 @@
  * 
  */
 
+#include "config.h"
+
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <ctype.h>
@@ -155,7 +157,7 @@ static gboolean sieve_read_chunk_cb(SockInfo *source,
 
 		if (read_len == -1 &&
 				session->state == SESSION_DISCONNECTED) {
-			g_warning ("sock_read: session disconnected");
+			g_warning("sock_read: session disconnected");
 			if (session->io_tag > 0) {
 				g_source_remove(session->io_tag);
 				session->io_tag = 0;
@@ -984,6 +986,8 @@ static void sieve_session_destroy(Session *session)
 	sessions = g_slist_remove(sessions, (gconstpointer)session);
 	g_slist_free_full(sieve_session->send_queue,
 			(GDestroyNotify)command_abort);
+	if (sieve_session->config)
+		sieve_prefs_account_free_config(sieve_session->config);
 }
 
 static void sieve_connect_finished(Session *session, gboolean success)
@@ -1036,6 +1040,7 @@ static SieveSession *sieve_session_new(PrefsAccount *account)
 	SESSION(session)->connect_finished = sieve_connect_finished;
 	session_set_recv_message_notify(SESSION(session), sieve_recv_message, NULL);
 
+	session->config = NULL;
 	sieve_session_reset(session);
 	return session;
 }
@@ -1058,9 +1063,12 @@ static void sieve_session_reset(SieveSession *session)
 	session->state = SIEVE_CAPABILITIES;
 #ifdef USE_GNUTLS
 	session->tls_init_done = FALSE;
+	SESSION(session)->use_tls_sni = account->use_tls_sni;
 #endif
 	session->avail_auth_type = 0;
 	session->auth_type = 0;
+	if (session->config)
+		sieve_prefs_account_free_config(session->config);
 	session->config = config;
 	session->host = config->use_host ? config->host : account->recv_server;
 	session->port = config->use_port ? config->port : SIEVE_PORT;
