@@ -386,7 +386,7 @@ static void spamassassin_create_widget_func(PrefsPage * _page,
 			_("Messages larger than this will not be checked"));
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(max_size_spinbtn), TRUE);
 
-	max_size_kb_label = gtk_label_new(_("KB"));
+	max_size_kb_label = gtk_label_new(_("KiB"));
 	gtk_widget_show(max_size_kb_label);
 	gtk_box_pack_start(GTK_BOX(hbox_max_size), max_size_kb_label, FALSE, FALSE, 0);
 
@@ -394,7 +394,7 @@ static void spamassassin_create_widget_func(PrefsPage * _page,
 	gtk_widget_show(hbox_timeout);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_timeout, TRUE, TRUE, 0);
 
-	timeout_label = gtk_label_new(_("Timeout"));
+	timeout_label = gtk_label_new(_("Timeout (secs)"));
 	gtk_widget_show(timeout_label);
 	gtk_box_pack_start(GTK_BOX(hbox_timeout), timeout_label, FALSE, FALSE, 0);
 
