@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2018 Colin Leroy and the Claws Mail team
+ * Copyright (C) 1999-2022 the Claws Mail team and Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -230,7 +230,7 @@ static gchar *get_tmpfile(VCalViewer *vcalviewer)
 		debug_print("creating %s\n", tmpfile);
 
 		if (procmime_get_part(tmpfile, vcalviewer->mimeinfo) < 0) {
-			g_warning("Can't get mimepart file");	
+			g_warning("can't get mimepart file");	
 			g_free(tmpfile);
 			return NULL;
 		}
@@ -555,17 +555,14 @@ void vcalviewer_display_event (VCalViewer *vcalviewer, VCalEvent *event)
 /* start */
 	if (event->start && *(event->start)) {
 		if (event->recur && *(event->recur)) {
-			gchar *tmp = g_strdup_printf(g_strconcat("%s <span weight=\"bold\">",
-							_("(this event recurs)"),"</span>", NULL),
-					event->start);
+			gchar *tmp = g_strdup_printf("%s <span weight=\"bold\">%s</span>",
+							_("(this event recurs)"), event->start);
 			GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->start), tmp);
 			gtk_label_set_use_markup(GTK_LABEL(vcalviewer->start), TRUE);
 			g_free(tmp);
 		} else if (event->rec_occurrence) {
-			gchar *tmp = g_strdup_printf(g_strconcat("%s <span weight=\"bold\">",
-							_("(this event is part of a recurring event)"),
-							"</span>", NULL),
-					event->start);
+			gchar *tmp = g_strdup_printf("%s <span weight=\"bold\">%s</span>",
+							_("(this event is part of a recurring event)"), event->start);
 			GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->start), tmp);
 			gtk_label_set_use_markup(GTK_LABEL(vcalviewer->start), TRUE);
 			g_free(tmp);
@@ -735,6 +732,8 @@ static void vcalviewer_get_reply_values(VCalViewer *vcalviewer, MimeInfo *mimein
 		vcalviewer_display_event(vcalviewer, saved_event);
 		vcal_manager_free_event(saved_event);
 		return;
+	} else if (saved_event) {
+		vcal_manager_free_event(saved_event);
 	}
 
 	if (vcalviewer->event->organizer) {
@@ -927,6 +926,8 @@ static gboolean vcalviewer_uribtn_cb(GtkButton *widget, gpointer data)
 
 void vcalendar_refresh_folder_contents(FolderItem *item)
 {
+	g_return_if_fail(item != NULL);
+
 	Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	if (folder && item->folder == folder) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
