@@ -795,13 +795,15 @@ static void delete_path(GSList ** p_filters, const gchar * path)
                                 prefixlen = destlen - pathlen;
                                 suffix = action->destination + prefixlen;
                                 
-                                if (suffix && !strncmp(path, suffix, pathlen)) {
-                                        filteringprop_free(filtering);
+                                if ((suffix && !strncmp(path, suffix, pathlen)) && filtering) {
                                         filters = g_slist_remove(filters, filtering);
+                                        filteringprop_free(filtering);
+                                        filtering = NULL;
                                 }
-                        } else if (strcmp(action->destination, path) == 0) {
-                                filteringprop_free(filtering);
+                        } else if ((strcmp(action->destination, path) == 0) && filtering) {
                                 filters = g_slist_remove(filters, filtering);
+                                filteringprop_free(filtering);
+                                filtering = NULL;
                         }
                 }
         }                
@@ -1474,7 +1476,7 @@ static gboolean prefs_filtering_check_mod(gboolean check_changed_list)
 	gchar * str;
 	gchar * filtering_str;
 	gint row = 1;
-        AlertValue val;
+	AlertValue val;
 	
 	prop = prefs_filtering_dialog_to_filtering(FALSE);
 	
@@ -1483,6 +1485,8 @@ static gboolean prefs_filtering_check_mod(gboolean check_changed_list)
 					 _("The list of filtering rules have been modified. Close anyway?"),
 					 GTK_STOCK_CLOSE, _("_Continue editing"), NULL,
 					 ALERTFOCUS_SECOND) != G_ALERTDEFAULT) {
+			if (prop != NULL)
+				filteringprop_free(prop);
 			return TRUE;
 		}
 	}
