@@ -74,7 +74,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	cm_return_if_fail(rcfile != NULL);
 
 	if (encoding != NULL)
-		g_warning("Encoding is ignored");
+		g_warning("encoding is ignored");
 
 	debug_print("Reading configuration...\n");
 
@@ -172,7 +172,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 				tmp = g_strdup("");
 			}
 			if (!tmp) {
-				g_warning("Failed to convert character set.");
+				g_warning("failed to convert character set");
 				tmp = g_strdup(value);
 			}
 			g_free(*((gchar **)param[i].data));
@@ -213,7 +213,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 #define TRY(func) \
 if (!(func)) \
 { \
-	g_warning("Failed to write configuration to file"); \
+	g_warning("failed to write configuration to file"); \
 	if (orig_fp) claws_fclose(orig_fp); \
 	prefs_file_close_revert(pfile); \
 	g_free(rcpath); \
@@ -241,7 +241,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 	}
 
 	if ((pfile = prefs_write_open(rcpath)) == NULL) {
-		g_warning("Failed to write configuration to file");
+		g_warning("failed to write configuration to file");
 		if (orig_fp) claws_fclose(orig_fp);
 		g_free(rcpath);
 		return;
@@ -297,7 +297,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 
 	if (orig_fp) claws_fclose(orig_fp);
 	if (prefs_file_close(pfile) < 0)
-		g_warning("Failed to write configuration to file");
+		g_warning("failed to write configuration to file");
 	g_free(rcpath);
 
 	debug_print("Configuration is saved.\n");
@@ -397,7 +397,7 @@ void prefs_set_default(PrefParam *param)
 								    CS_INTERNAL)
 						: g_strdup("");
 					if (!tmp) {
-						g_warning("Failed to convert character set.");
+						g_warning("failed to convert character set");
 						tmp = g_strdup(envstr);
 					}
 					*((gchar **)param[i].data) = tmp;
@@ -625,7 +625,7 @@ void prefs_set_data_from_entry(PrefParam *pparam)
 		*((gint *)pparam->data) = atoi(entry_str);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkEntry widget: %d",
+		g_warning("invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -643,7 +643,7 @@ void prefs_set_escaped_data_from_entry(PrefParam *pparam)
 		*str = pref_get_pref_from_entry(GTK_ENTRY(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
+		g_warning("invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -668,7 +668,7 @@ void prefs_set_entry(PrefParam *pparam)
 				   itos(*((gushort *)pparam->data)));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkEntry widget: %d",
+		g_warning("invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -686,7 +686,7 @@ void prefs_set_entry_from_escaped(PrefParam *pparam)
 				   *str ? *str : "");
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
+		g_warning("invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -738,7 +738,7 @@ void prefs_set_data_from_text(PrefParam *pparam)
 		g_free(text);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkText widget: %d",
+		g_warning("invalid PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -756,7 +756,7 @@ void prefs_set_escaped_data_from_text(PrefParam *pparam)
 		*str = pref_get_pref_from_textview(GTK_TEXT_VIEW(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkText widget: %d",
+		g_warning("invalid escaped PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -798,7 +798,7 @@ void prefs_set_text(PrefParam *pparam)
 		gtk_text_buffer_insert(buffer, &iter, buf, -1);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkTextView widget: %d",
+		g_warning("invalid PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -816,7 +816,7 @@ void prefs_set_text_from_escaped(PrefParam *pparam)
 				 *str ? *str : "");
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkTextView widget: %d",
+		g_warning("invalid escaped PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -855,7 +855,7 @@ void prefs_set_data_from_spinbtn(PrefParam *pparam)
 			(GTK_SPIN_BUTTON(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
+		g_warning("invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
@@ -874,7 +874,7 @@ void prefs_set_spinbtn(PrefParam *pparam)
 					  (gfloat)*((gushort *)pparam->data));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
+		g_warning("invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
@@ -1044,7 +1044,7 @@ static gboolean prefs_read_config_from_cache(PrefParam *param, const gchar *labe
 	sections_table = g_hash_table_lookup(whole_cache, rcfile);
 	
 	if (sections_table == NULL) {
-		g_warning("Can't find %s in the whole cache", rcfile?rcfile:"(null)");
+		g_warning("can't find %s in the whole cache", rcfile?rcfile:"(null)");
 		return FALSE;
 	}
 	values_table = g_hash_table_lookup(sections_table, label);
