@@ -341,7 +341,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	COLOR_BUTTON_PACK_START(hbox, COL_DIFF_HUNK,
 	/* TRANSLATORS: A hunk is a section of the patch indicating how the files differ */
-				C_("Tooltip.", "Pick color for hunk lines"));
+				C_("Tooltip", "Pick color for hunk lines"));
 
 	COLOR_LABEL_PACK_START(hbox, COL_DIFF_HUNK,
 	/* TRANSLATORS: A hunk is a section of the patch indicating how the files differ */
@@ -588,7 +588,7 @@ static void quote_color_set_dialog(GtkWidget *widget, gpointer data)
 			title = g_strdup(color_dialog_title[ctype]);
 			rgbvalue = prefs_common.color[ctype];
 		} else {
-			g_warning("Unrecognized datatype '%s' in quote_color_set_dialog", type);
+			g_warning("unrecognized datatype '%s' in quote_color_set_dialog", type);
 			return;
 		}
 	}
@@ -654,7 +654,7 @@ static void quote_colors_set_dialog_ok(GtkWidget *widget, gpointer data)
 				folderview_set_target_folder_color(prefs_common.color[ctype]);
 			}
 		} else {
-			g_warning("Unrecognized datatype '%s' in quote_color_set_dialog_ok", type);
+			g_warning("unrecognized datatype '%s' in quote_color_set_dialog_ok", type);
 		}
 	}
 
