@@ -235,7 +235,7 @@ static gchar *vcard_get_line( VCardFile *cardFile ) {
 	start = cardFile->bufptr;
 	len = strlen( start );
 	end = start + len;
-	strncpy( buf, start, len );
+	memcpy( buf, start, len );
 	buf[ len ] = '\0';
 	g_strstrip(buf);
 	cardFile->bufptr = end + 1;
@@ -390,8 +390,8 @@ static gchar *vcard_unescape_qp( gchar *value ) {
 		return NULL;
 		
 	len = strlen(value);
-	res = g_malloc(len);
-	qp_decode_const(res, len-1, value);
+	res = g_malloc(len + 1);
+	qp_decode_const(res, len, value);
 	if (!g_utf8_validate(res, -1, NULL)) {
 		gchar *mybuf = g_malloc(strlen(res)*2 +1);
 		conv_localetodisp(mybuf, strlen(res)*2 +1, res);
