@@ -1,7 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Colin Leroy <colin@colino.net>
- * and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -168,8 +167,8 @@ static PrefParam template_params[] = {
 	 &tmpl.smtpuser, P_STRING, NULL, NULL, NULL},
 	{"smtppass", "",
 	 &tmpl.smtppass, P_STRING, NULL, NULL, NULL},
-	{"recvtype", A_POP3,
-	 &tmpl.recvtype, P_INT, NULL, NULL, NULL},
+	{"recvtype", "0",
+	 &tmpl.recvtype, P_ENUM, NULL, NULL, NULL},
 	{"recvserver", "pop.$DOMAIN",
 	 &tmpl.recvserver, P_STRING, NULL, NULL, NULL},
 	{"recvuser", "$LOGIN",
@@ -239,7 +238,7 @@ static gchar *accountrc_tmpl =
 	"\n"
 	"#recvtype can be:\n"
 	"#0 for pop3\n"
-	"#2  for imap\n"
+	"#1  for imap\n"
 	"#3  for a local mbox file\n"
 	"#recvtype=\n"
 	"\n"
@@ -273,26 +272,26 @@ static gchar *accountrc_tmpl =
 	"#mailbox=\n"
 	"\n"
 	"#whether to use encryption on SMTP connections\n"
-	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
 	"#smtpssl=\n"
 	"\n"
 	"#whether to use encryption on POP3 or IMAP connections\n"
-	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
 	"#recvssl=\n"
 	"\n"
-	"#SSL/TLS client certificate path for SMTP\n"
+	"#TLS client certificate path for SMTP\n"
 	"#default is empty (no certificate)\n"
 	"#smtpssl_cert=\n"
 	"\n"
-	"#SSL/TLS client certificate path for POP/IMAP\n"
+	"#TLS client certificate path for POP/IMAP\n"
 	"#default is empty (no certificate)\n"
 	"#recvssl_cert=\n"
 	"\n"
-	"#SSL/TLS client certificate password for SMTP\n"
+	"#TLS client certificate password for SMTP\n"
 	"#default is empty (no password)\n"
 	"#smtpssl_cert_pass=\n"
 	"\n"
-	"#SSL/TLS client certificate password for POP/IMAP\n"
+	"#TLS client certificate password for POP/IMAP\n"
 	"#default is empty (no password)\n"
 	"#recvssl_cert_pass=\n"
 	;
@@ -538,7 +537,7 @@ static void write_welcome_email(WizardWindow *wizard)
 		"Face: %s\n"
 		"Content-Type: text/plain; charset=UTF-8\n",
 		enc_from_name,
-		USERS_ML_ADDR,
+		WELCOME_MSG_ADDR,
 		enc_to_name,
 		gtk_entry_get_text(GTK_ENTRY(wizard->email)),
 		date, enc_subject, XFACE, FACE);
@@ -849,7 +848,7 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 
 	/* create the titlebar */
 	hbox = gtk_hbox_new (FALSE, 12);
-	image = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_ICON);
+	image = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_ICON);
 	gtk_box_pack_start (GTK_BOX(hbox), image, FALSE, FALSE, 0);
      	title_string = g_strconcat ("<span size=\"xx-large\" weight=\"ultrabold\">", title ? title : "", "</span>", NULL);
 	w = gtk_label_new (title_string);
@@ -1069,7 +1068,7 @@ static void cert_browse_cb(GtkWidget *widget, gpointer data)
 
 	utf8_filename = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 	if (!utf8_filename) {
-		g_warning("cert_browse_cb(): failed to convert character set.");
+		g_warning("cert_browse_cb(): failed to convert character set");
 		utf8_filename = g_strdup(filename);
 	}
 	gtk_entry_set_text(dest, utf8_filename);
@@ -1164,7 +1163,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL/TLS to connect to SMTP server"));
+					_("Use TLS to connect to SMTP server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->smtp_use_ssl),
 			tmpl.smtpssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_ssl, FALSE, FALSE, 0);
@@ -1187,7 +1186,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox_spc = gtk_hbox_new (FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	label = gtk_label_new(_("Client TLS certificate (optional)"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(smtp_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
@@ -1584,7 +1583,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->recv_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL/TLS to connect to receiving server"));
+					_("Use TLS to connect to receiving server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->recv_use_ssl),
 			tmpl.recvssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_ssl, FALSE, FALSE, 0);
@@ -1607,7 +1606,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox_spc = gtk_hbox_new (FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	label = gtk_label_new(_("Client TLS certificate (optional)"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);	
 	gtk_table_attach(GTK_TABLE(recv_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
@@ -1822,7 +1821,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Welcome to Claws Mail"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
@@ -1904,7 +1903,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Configuration finished"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
